@@ -8,7 +8,7 @@ package Net::Prometheus;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
@@ -17,6 +17,7 @@ use List::Util 1.29 qw( pairmap );
 use Net::Prometheus::Gauge;
 use Net::Prometheus::Counter;
 use Net::Prometheus::Summary;
+use Net::Prometheus::Histogram;
 
 =head1 NAME
 
@@ -86,6 +87,11 @@ sub new
 
 =head2 register
 
+   $collector = $prometheus->register( $collector )
+
+Registers a new L<collector|/COLLECTORS> to be collected from by the C<render>
+method. The collector instance itself is returned, for convenience.
+
 =cut
 
 sub register
@@ -102,6 +108,10 @@ sub register
 
 =head2 unregister
 
+   $prometheus->unregister( $collector )
+
+Removes a previously-registered collector.
+
 =cut
 
 sub unregister
@@ -169,6 +179,61 @@ sub new_summary
    return $self->register( Net::Prometheus::Summary->new( %args ) );
 }
 
+=head2 new_histogram
+
+   $histogram = $prometheus->new_histogram( %args )
+
+Constructs a new L<Net::Prometheus::Histogram> using the arguments given
+and registers it with the exporter. The newly-constructed summary is returned.
+
+=cut
+
+sub new_histogram
+{
+   my $self = shift;
+   my %args = @_;
+
+   return $self->register( Net::Prometheus::Histogram->new( %args ) );
+}
+
+=head2 new_metricgroup
+
+   $group = $prometheus->new_metricgroup( %args )
+
+Returns a new Metric Group instance as a convenience for registering multiple
+metrics using the same C<namespace> and C<subsystem> arguments. Takes the
+following named arguments:
+
+=over
+
+=item namespace => STR
+
+=item subsystem => STR
+
+String values to pass by default into new metrics the group will construct.
+
+=back
+
+Once constructed, the group acts as a proxy to the other C<new_*> methods,
+passing in these values as overrides.
+
+   $gauge = $group->new_gauge( ... )
+   $counter = $group->new_counter( ... )
+   $summary = $group->new_summary( ... )
+   $histogram = $group->new_histogram( ... )
+
+=cut
+
+sub new_metricgroup
+{
+   my $self = shift;
+   my ( %args ) = @_;
+
+   return Net::Prometheus::_MetricGroup->new(
+      $self, %args
+   );
+}
+
 =head2 render
 
    $str = $prometheus->render
@@ -257,25 +322,61 @@ sub psgi_app
    };
 }
 
+{
+   package
+      Net::Prometheus::_MetricGroup;
+
+   sub new
+   {
+      my $class = shift;
+      my ( $prometheus, %args ) = @_;
+      return bless {
+         prometheus => $prometheus,
+         namespace  => $args{namespace},
+         subsystem  => $args{subsystem},
+      }, $class;
+   }
+
+   foreach my $method (qw( new_gauge new_counter new_summary new_histogram )) {
+      no strict 'refs';
+      *$method = sub {
+         my $self = shift;
+         $self->{prometheus}->$method(
+            namespace => $self->{namespace},
+            subsystem => $self->{subsystem},
+            @_,
+         );
+      };
+   }
+}
+
+=head1 COLLECTORS
+
+The toplevel C<Net::Prometheus> object stores a list of "collector" instances,
+which are used to generate the values that will be made visible via the
+L</render> method. A collector can be any object instance that has a method
+called C<collect>, which when invoked is passed no arguments and expected to
+return a list of L<Net::Prometheus::Types/MetricSamples> structures.
+
+   @metricsamples = $collector->collect
+
+The L<Net::Prometheus::Metric> class is already a valid collector (and hence,
+so too are the individual metric type subclasses). This interface allows the
+creation of new custom collector objects, that more directly collect
+information to be exported.
+
+=cut
+
 =head1 TODO
 
 =over 8
 
 =item *
 
-Document the Collector / Metric distinction. Document how to make custom
-Collectors
-
-=item *
-
 Process collector.
 
 =item *
 
-Callback gauges.
-
-=item *
-
 Split Registry out from toplevel instance.
 
 =item *
