@@ -9,12 +9,14 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
 use constant _type => "counter";
 
+__PACKAGE__->MAKE_child_class;
+
 =head1 NAME
 
 C<Net::Prometheus::Counter> - a monotonically-increasing counter metric
@@ -56,8 +58,6 @@ L<Net::Prometheus::Metric>.
 
 =cut
 
-__PACKAGE__->make_childlabel_method( $_ ) for qw( inc );
-
 sub new
 {
    my $class = shift;
@@ -66,6 +66,8 @@ sub new
 
    $self->{values} = {};
 
+   $self->inc( 0 ) if !$self->labelcount;
+
    return $self;
 }
 
@@ -84,6 +86,7 @@ supplied and must be non-negative.
 
 =cut
 
+__PACKAGE__->MAKE_child_method( 'inc' );
 sub _inc_child
 {
    my $self = shift;
