@@ -9,12 +9,14 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
 use constant _type => "gauge";
 
+__PACKAGE__->MAKE_child_class;
+
 =head1 NAME
 
 C<Net::Prometheus::Gauge> - a snapshot value-reporting metric
@@ -42,6 +44,21 @@ snapshot of state at some instant in time. This is often used to report on the
 current usage of resources by the instrumented program, in a way that can
 decrease as well as increase. It is a subclass of L<Net::Prometheus::Metric>.
 
+=head2 Value-Reporting Functions
+
+As an alternative to using the C<set> method to update the value of the gauge,
+a callback function can be used instead which should return the current value
+to report for that gauge. This function is invoked at collection time, meaning
+the reported value is up-to-date.
+
+These functions are invoked inline as part of the collection process, so they
+should be as small and lightweight as possible. Typical applications involve
+reporting the size of an array or hash within the implementation's code.
+
+   $gauge->set_function( sub { scalar @items } );
+
+   $gauge->set_function( sub { scalar keys %things } );
+
 =cut
 
 =head1 CONSTRUCTOR
@@ -56,15 +73,16 @@ L<Net::Prometheus::Metric>.
 
 =cut
 
-__PACKAGE__->make_childlabel_method( $_ ) for qw( set inc dec );
-
 sub new
 {
    my $class = shift;
 
    my $self = $class->SUPER::new( @_ );
 
-   $self->{values} = {};
+   $self->{values}    = {};
+   $self->{functions} = {};
+
+   $self->inc( 0 ) if !$self->labelcount;
 
    return $self;
 }
@@ -85,6 +103,7 @@ If the gauge has any labels defined, the values for them must be given first.
 
 =cut
 
+__PACKAGE__->MAKE_child_method( 'set' );
 sub _set_child
 {
    my $self = shift;
@@ -93,6 +112,31 @@ sub _set_child
    $self->{values}{$labelkey} = $value;
 }
 
+=head2 set_function
+
+   $gauge->set_function( [ @label_values ], $func )
+
+   $child->set_function( $func )
+
+Sets a value-returning callback function for the gauge. If the gauge is
+labeled, each label combination requires its own function.
+
+When invoked, the function will be passed no arguments and is expected to
+return a single value
+
+   $value = $func->()
+
+=cut
+
+__PACKAGE__->MAKE_child_method( 'set_function' );
+sub _set_function_child
+{
+   my $self = shift;
+   my ( $labelkey, $func ) = @_;
+
+   $self->{functions}{$labelkey} = $func;
+}
+
 =head2 inc
 
    $gauge->inc( [ @label_values ], $delta )
@@ -104,6 +148,7 @@ supplied.
 
 =cut
 
+__PACKAGE__->MAKE_child_method( 'inc' );
 sub _inc_child
 {
    my $self = shift;
@@ -122,6 +167,7 @@ supplied.
 
 =cut
 
+__PACKAGE__->MAKE_child_method( 'dec' );
 sub _dec_child
 {
    my $self = shift;
@@ -135,10 +181,13 @@ sub samples
 {
    my $self = shift;
 
-   my $values = $self->{values};
+   my $values    = $self->{values};
+   my $functions = $self->{functions};
 
    return map {
-      $self->make_sample( undef, $_, $values->{$_} )
+      $self->make_sample( undef, $_,
+         $functions->{$_} ? $functions->{$_}->() : $values->{$_}
+      )
    } sort keys %$values;
 }
 
