@@ -1,7 +1,7 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2016-2018 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2016 -- leonerd@leonerd.org.uk
 
 package Net::Prometheus::Histogram;
 
@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.07_001';
+our $VERSION = '0.03';
 
 use Carp;
 use List::Util 1.33 qw( any );
@@ -73,7 +73,7 @@ L<Net::Prometheus::Metric>, and additionally the following:
 
 =item buckets => ARRAY
 
-A reference to an ARRAY containing numerical upper bounds for the buckets.
+A reference to an ARRAY containing numerical lower bounds for the buckets.
 
 =back
 
@@ -108,13 +108,12 @@ sub new
 
 =head2 observe
 
-   $histogram->observe( @label_values, $value )
-   $histogram->observe( \%labels, $value )
+   $histogram->observe( [ @label_values ], $value )
 
    $child->observe( $value )
 
 Increment the histogram sum by the given value, and each bucket count by 1
-where the value is less than or equal to the bucket upper bound.
+where the value is less than or equal to the bucket lower bound.
 
 =cut
 
@@ -125,7 +124,7 @@ sub _observe_child
    my ( $labelkey, $value ) = @_;
 
    my $bounds  = $self->{bounds};
-   my $buckets = $self->{bucketcounts}{$labelkey} ||= [ ( 0 ) x ( @$bounds + 1 ) ];
+   my $buckets = $self->{bucketcounts}{$labelkey} //= [ ( 0 ) x ( @$bounds + 1 ) ];
 
    $value <= $bounds->[$_] and $buckets->[$_]++ for 0 .. $#$bounds;
    $buckets->[scalar @$bounds]++;
