@@ -8,13 +8,15 @@ package Net::Prometheus::Metric;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 our @CARP_NOT = qw( Net::Prometheus );
 
 use Net::Prometheus::Types qw( Sample MetricSamples );
 
+use constant CHILDCLASS => "Net::Prometheus::Metric::_Child";
+
 =head1 NAME
 
 C<Net::Prometheus::Metric> - the base class for observed metrics
@@ -41,18 +43,6 @@ L<Net::Prometheus::Summary>
 
 =cut
 
-sub make_childlabel_method
-{
-   my $class = shift;
-   my ( $method ) = @_;
-
-   no strict 'refs';
-   *{"${class}::${method}"} = sub {
-      my $self = shift;
-      $self->labels( splice @_, 0, $self->labelcount )->$method( @_ );
-   };
-}
-
 =head1 CONSTRUCTOR
 
 =cut
@@ -205,34 +195,91 @@ sub labels
 
    $self->{labelvalues}{$labelkey} = \@values;
 
-   return Net::Prometheus::Metric::_Child->new(
+   return $self->CHILDCLASS->new(
       $self, $labelkey
    );
 }
 
+{
+   package
+      Net::Prometheus::Metric::_Child;
+
+   use constant {
+      METRIC   => 0,
+      LABELKEY => 1,
+   };
+
+   sub new
+   {
+      my $class = shift;
+      my ( $metric, $labelkey ) = @_;
+      return bless [ $metric, $labelkey ], $class;
+   }
+
+   sub metric   { shift->[METRIC] }
+   sub labelkey { shift->[LABELKEY] }
+}
+
+# A metaclass method for declaring the child class
+sub MAKE_child_class
+{
+   my $class = shift;
+
+   my $childclass = "${class}::_Child";
+
+   no strict 'refs';
+
+   # The careful ordering of these two lines should make it possible to
+   #   further subclass metrics and metric child classes recursively
+   @{"${childclass}::ISA"} = $class->CHILDCLASS;
+   *{"${class}::CHILDCLASS"} = sub() { $childclass };
+}
+
+# A metaclass method for declaring what Metric subclass methods are proxied
+#   via child instances
+sub MAKE_child_method
+{
+   my $class = shift;
+   my ( $method ) = @_;
+
+   no strict 'refs';
+   *{"${class}::${method}"} = sub {
+      my $self = shift;
+      $self->labels( splice @_, 0, $self->labelcount )->$method( @_ );
+   };
+
+   my $childmethod = "_${method}_child";
+
+   *{"${class}::_Child::${method}"} = sub {
+      my $self = shift;
+      $self->metric->$childmethod( $self->labelkey, @_ );
+   };
+}
+
 =head2 make_sample
 
-   $sample = $metric->make_sample( $suffix, $labelkey, $value )
+   $sample = $metric->make_sample( $suffix, $labelkey, $value, $extralabels )
 
 Returns a new L<Net::Prometheus::Types/Sample> structure to represent the
 given value, by expanding the opaque C<$labelkey> value into its actual label
 names and values and appending the given suffix (which may be an empty string)
 to the metric's fullname. If provided, the suffix will be separated by an
-underscore C<'_'>.
+underscore C<'_'>. If provided, C<$extralabels> provides more label names and
+values to be added to the sample.
 
 =cut
 
 sub make_sample
 {
    my $self = shift;
-   my ( $suffix, $labelkey, $value ) = @_;
+   my ( $suffix, $labelkey, $value, $extralabels ) = @_;
 
    my $labelnames  = $self->{labels};
    my $labelvalues = $self->{labelvalues}{$labelkey};
 
    return Sample(
       ( $suffix ? $self->fullname . "_$suffix" : $self->fullname ),
-      [ map { $labelnames->[$_], $labelvalues->[$_] } 0 .. $#$labelnames ],
+      [ ( map { $labelnames->[$_], $labelvalues->[$_] } 0 .. $#$labelnames ), @{ $extralabels || [] } ],
       $value,
    );
 }
@@ -265,34 +312,6 @@ sub samples
    croak "Abstract Net::Prometheus::Metric->samples invoked directly";
 }
 
-package
-   Net::Prometheus::Metric::_Child;
-
-use constant {
-   METRIC   => 0,
-   LABELKEY => 1,
-};
-
-sub new
-{
-   my $class = shift;
-   my ( $metric, $labelkey ) = @_;
-   return bless [ $metric, $labelkey ], $class;
-}
-
-sub metric   { shift->[METRIC] }
-sub labelkey { shift->[LABELKEY] }
-
-foreach my $method (qw( set inc dec observe )) {
-   my $childmethod = "_${method}_child";
-
-   no strict 'refs';
-   *$method = sub {
-      my $self = shift;
-      $self->[METRIC]->$childmethod( $self->[LABELKEY], @_ );
-   };
-}
-
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
