@@ -9,13 +9,15 @@ use strict;
 use warnings;
 use base qw( Net::Prometheus::Metric );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 use List::Util 1.33 qw( any );
 
 use constant _type => "summary";
 
+__PACKAGE__->MAKE_child_class;
+
 =head1 NAME
 
 C<Net::Prometheus::Summary> - summarise individual numeric observations
@@ -61,8 +63,6 @@ L<Net::Prometheus::Metric>.
 
 =cut
 
-__PACKAGE__->make_childlabel_method( $_ ) for qw( observe );
-
 sub new
 {
    my $class = shift;
@@ -76,6 +76,10 @@ sub new
    $self->{counts} = {};
    $self->{sums}   = {};
 
+   if( !$self->labelcount ) {
+      $self->{counts}{""} = $self->{sums}{""} = 0;
+   }
+
    return $self;
 }
 
@@ -89,6 +93,7 @@ Increment the summary sum by the given value, and the count by 1.
 
 =cut
 
+__PACKAGE__->MAKE_child_method( 'observe' );
 sub _observe_child
 {
    my $self = shift;
